@@ -2,7 +2,7 @@ package Data::Processor;
 
 use strict;
 use 5.010_001;
-our $VERSION = '1.0.8';
+our $VERSION = '1.0.9';
 
 use Carp;
 use Scalar::Util qw(blessed);
@@ -167,7 +167,6 @@ sub validate_schema {
                 regex => {
                     description => 'should this key be treated as a regular expression?',
                     optional => 1,
-                    default => 0,
                     validator => $bool
                 },
                 value => {
@@ -185,7 +184,6 @@ sub validate_schema {
                 optional => {
                     description => 'is this key optional ?',
                     optional => 1,
-                    default => 0,
                     validator => $bool,
                 },
                 default => {
@@ -195,13 +193,11 @@ sub validate_schema {
                 array => {
                     description => 'is the value of this key expected to be an array? In array mode, value and validator will be applied to each element of the array.',
                     optional => 1,
-                    default => 0,
                     validator => $bool
                 },
                 allow_empty => {
                     description => 'allow empty entries in an array',
                     optional => 1,
-                    default => 0,
                     validator => sub {
                         my ($value, $parent) = @_;
                         return 'allow_empty can only be set for array' if !$parent->{array};
@@ -311,10 +307,10 @@ sub merge_schema {
             }
 
             #merge members subtree recursively
-            exists $otherSubSchema->{$elem}->{members} && do {
+            if (exists $otherSubSchema->{$elem}->{members}) {
                 exists $subSchema->{$elem}->{members} || ($subSchema->{$elem}->{members} = {});
                 $mergeSubSchema->($subSchema->{$elem}->{members}, $otherSubSchema->{$elem}->{members});
-            };
+            }
 
             #check elements
             for my $key (qw(description example default error_msg regex array value)){
@@ -322,16 +318,23 @@ sub merge_schema {
             }
 
             #special handler for transformer
-            defined $otherSubSchema->{$elem}->{transformer} &&
-                croak "merging element '$elem': merging transformer not allowed";
+            if ($otherSubSchema->{$elem}->{transformer}) {
+                croak "merging element '$elem': merging conflicting transformers not allowed"
+                    if $subSchema->{$elem}->{transformer}
+                        && $subSchema->{$elem}->{transformer} != $otherSubSchema->{$elem}->{transformer};
+
+                $subSchema->{$elem}->{transformer} = $otherSubSchema->{$elem}->{transformer};
+            }
 
             #special handler for optional: set it mandatory if at least one is not optional
             delete $subSchema->{$elem}->{optional}
                 if !($subSchema->{$elem}->{optional} && $otherSubSchema->{$elem}->{optional});
 
             #special handler for validator: combine validator subs
-            $otherSubSchema->{$elem}->{validator} && do {
-                if (my $validator = $subSchema->{$elem}->{validator}){
+            if ($otherSubSchema->{$elem}->{validator}) {
+                if ((my $validator = $subSchema->{$elem}->{validator})
+                    && $subSchema->{$elem}->{validator} != $otherSubSchema->{$elem}->{validator}) {
+
                     $subSchema->{$elem}->{validator} = sub {
                         return $validator->(@_) // $otherSubSchema->{$elem}->{validator}->(@_);
                     };
@@ -340,7 +343,7 @@ sub merge_schema {
                     $subSchema->{$elem}->{validator}
                         = $otherSubSchema->{$elem}->{validator};
                 }
-            };
+            }
         }
     };
 
