@@ -15,7 +15,7 @@ sub pod_write{
         $pod_string .= ": $schema->{$key}->{description}"
             if $schema->{$key}->{description};
         $pod_string .= "\n\nDefault value: $schema->{$key}->{default}"
-            if $schema->{$key}->{default};
+            if defined $schema->{$key}->{default};
         $pod_string .= "\n\n";
         if ($schema->{$key}->{members}){
             $pod_string .= "$key has the following members:\n\n";
